==> pass-import-3.2.tgz: lib/python3.8/site-packages/pass_import/managers/__init__.py <==
from pass_import.managers.aegis import Aegis, AegisCipher
from pass_import.managers.andotp import AndOTP
from pass_import.managers.applekeychain import AppleKeychain
from pass_import.managers.bitwarden import BitwardenCSV, BitwardenJSON
from pass_import.managers.blur import BlurCSV, BlurJSON
from pass_import.managers.buttercup import Buttercup
from pass_import.managers.chrome import ChromeCSV, ChromeCSVSQLite
from pass_import.managers.clipperz import ClipperzHTML
from pass_import.managers.csv import GenericCSV
from pass_import.managers.dashlane import DashlaneCSV, DashlaneJSON
from pass_import.managers.encryptr import Encryptr
from pass_import.managers.enpass import Enpass, Enpass6
from pass_import.managers.figaropm import FigaroPM
from pass_import.managers.firefox import Firefox, FirefoxPasswordExporter
from pass_import.managers.freeotp import FreeOTPPlus
from pass_import.managers.gnomeauthenticator import GnomeAuthenticator
from pass_import.managers.gnomekeyring import GnomeKeyring
from pass_import.managers.gorilla import Gorilla
from pass_import.managers.keepass import Keepass, KeepassCSV, KeepassXML
from pass_import.managers.keepassx import KeepassxXML
from pass_import.managers.keepassx2 import Keepassx2CSV, Keepassx2KDBX
from pass_import.managers.keepassxc import KeepassxcCSV, KeepassxcKDBX
from pass_import.managers.keeper import KeeperCSV
from pass_import.managers.lastpass import LastpassCSV
from pass_import.managers.myki import Myki
from pass_import.managers.networkmanager import NetworkManager
from pass_import.managers.onepassword import (OnePassword4CSV, OnePassword4PIF,
                                              OnePasswordCSV)
from pass_import.managers.padlock import PadlockCSV
from pass_import.managers.passman import PassmanCSV, PassmanJSON
from pass_import.managers.passpack import Passpack
from pass_import.managers.passpie import Passpie
from pass_import.managers.passwordstore import PasswordStore
from pass_import.managers.gopass import Gopass
from pass_import.managers.pwsafe import Pwsafe
from pass_import.managers.revelation import Revelation
from pass_import.managers.roboform import Roboform
from pass_import.managers.saferpass import SaferPass
from pass_import.managers.upm import UPM
from pass_import.managers.zoho import ZohoCSV, ZohoCSVVault

==> pass-import-3.5p2.tgz: lib/python3.12/site-packages/pass_import/managers/__init__.py <==
from pass_import.managers.aegis import Aegis, AegisCipher
from pass_import.managers.andotp import AndOTP
from pass_import.managers.applekeychain import AppleKeychain
from pass_import.managers.bitwarden import (BitwardenCSV, BitwardenJSON,
                                            BitwardenOrgCSV, BitwardenOrgJSON)
from pass_import.managers.blur import BlurCSV, BlurJSON
from pass_import.managers.buttercup import Buttercup
from pass_import.managers.chrome import ChromeCSV, ChromeCSVSQLite
from pass_import.managers.clipperz import ClipperzHTML
from pass_import.managers.csv import GenericCSV
from pass_import.managers.dashlane import DashlaneCSV, DashlaneJSON
from pass_import.managers.encryptr import Encryptr
from pass_import.managers.enpass import Enpass, Enpass6
from pass_import.managers.figaropm import FigaroPM
from pass_import.managers.firefox import Firefox, FirefoxPasswordExporter
from pass_import.managers.freeotp import FreeOTPPlus
from pass_import.managers.gnomeauthenticator import GnomeAuthenticator
from pass_import.managers.gnomekeyring import GnomeKeyring
from pass_import.managers.gorilla import Gorilla
from pass_import.managers.keepass import Keepass, KeepassCSV, KeepassXML
from pass_import.managers.keepassx import KeepassxXML
from pass_import.managers.keepassx2 import Keepassx2CSV, Keepassx2KDBX
from pass_import.managers.keepassxc import KeepassxcCSV, KeepassxcKDBX
from pass_import.managers.keeper import KeeperCSV
from pass_import.managers.lastpass import LastpassCLI, LastpassCSV
from pass_import.managers.myki import Myki
from pass_import.managers.networkmanager import NetworkManager
from pass_import.managers.nordpass import NordPassCSV
from pass_import.managers.onepassword import (
    OnePassword8CSV, OnePasswordCSV, OnePassword4CSV, OnePassword4PIF)
from pass_import.managers.padlock import PadlockCSV
from pass_import.managers.passman import PassmanCSV, PassmanJSON
from pass_import.managers.passpack import Passpack
from pass_import.managers.passpie import Passpie
from pass_import.managers.passwordstore import PasswordStore
from pass_import.managers.gopass import Gopass
from pass_import.managers.pwsafe import Pwsafe
from pass_import.managers.revelation import Revelation
from pass_import.managers.roboform import Roboform
from pass_import.managers.safeincloud import SafeInCloudCSV
from pass_import.managers.saferpass import SaferPass
from pass_import.managers.sphinx import Sphinx
from pass_import.managers.upm import UPM
from pass_import.managers.zoho import ZohoCSV, ZohoCSVVault
